@@ -56,7 +56,10 @@ public:
 	myTCPSocket(InetAddress &ia);
 };
 
-myTCPSocket::myTCPSocket(InetAddress &ia) : TCPSocket(ia, 4096) {}
+myTCPSocket::myTCPSocket(InetAddress &ia) : TCPSocket(ia, 4096) 
+{
+	cout << "binding segsize: " << getSegmentSize() << endl;
+}
 
 bool myTCPSocket::onAccept(const InetHostAddress &ia, tpport_t port)
 {
@@ -66,8 +69,9 @@ bool myTCPSocket::onAccept(const InetHostAddress &ia, tpport_t port)
 
 int main(int argc, char *argv[])
 {
+	tpport_t port;
 	int i;
-	tcpstream tcp;
+	TCPStream tcp;
 	InetAddress addr;
 	addr = "255.255.255.255";
 	cout << "testing addr: " << addr << ":" << 4096 << endl;
@@ -82,16 +86,19 @@ int main(int argc, char *argv[])
 		myTCPSocket server(addr);
 		while(server.isPendingConnection(30000))
 		{
-			tcp.open(server);
+			tcp.connect(server);
+
 //			tcp.unsetf(ios::binary);
-			tcp << "welcome to " << addr << endl;
+			tcp << "welcome to " << addr << "; segment size=" << tcp.getSegmentSize() << endl;
+			tcp << "connected from " << tcp.getPeer(&port) << endl;
+
 			if(tcp.isPending(Socket::pendingInput, 2000))
 			{
 				tcp >> i;
 				tcp << "user entered " << i << endl;
 			}
 			tcp << "exiting now" << endl;
-			tcp.close();
+			tcp.disconnect();
 		}
 	}
 	catch(SockException& e)
