@@ -90,7 +90,7 @@ private:
 	static MemPager *pager;
 	static char **idx;
 
-#if defined(__GNUC__) || !defined(__hpux)
+#ifdef	CCXX_PACKED
 #pragma	pack(1)
 #endif
 
@@ -110,7 +110,7 @@ private:
 		}	ministring;
 	}	content;
 
-#if defined(__GNUC__) || !defined(__hpux)
+#ifdef	CCXX_PACKED
 #pragma	pack()
 #endif
 
