@@ -88,11 +88,13 @@ typedef DWORD   timeout_t;
 
 #ifdef	CCXX_NAMESPACES
 namespace ost {
+#ifdef __BORLANDC__
 # if __BORLANDC__ >= 0x0560
 using std::time_t;
 using std::tm;
 # endif
 #endif
+#endif
 
 #ifdef	HAVE_GCC_CXX_BITS_ATOMIC
 using namespace __gnu_cxx;
@@ -495,14 +497,14 @@ class __EXPORT AtomicCounter
 {
 #ifndef CCXX_USE_WIN32_ATOMIC
 private:
-#ifdef	HAVE_ATOMIC_AIX
+#if	defined(HAVE_ATOMIC_AIX)
 	volatile int counter;
-#elif   HAVE_GCC_BITS_ATOMIC
+#elif   defined(HAVE_GCC_BITS_ATOMIC)
 	volatile _Atomic_word counter;
-#elif   HAVE_GCC_CXX_BITS_ATOMIC
+#elif   defined(HAVE_GCC_CXX_BITS_ATOMIC)
 	volatile _Atomic_word counter;
 //	__gnu_cxx::_Atomic_word counter;
-#elif	HAVE_ATOMIC
+#elif	defined(HAVE_ATOMIC)
 	atomic_t atomic;
 #else
 	volatile int counter;
