@@ -114,7 +114,7 @@ Socket(accept(tcp.getSocket(), NULL, NULL))
 #endif
 
 SocketPort::SocketPort(SocketService *svc, const IPV4Address &ia, tpport_t port) :
-Socket(AF_INET, SOCK_DGRAM, 0)
+Socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP)
 {
 #ifdef WIN32
 	// FIXME: error handling
@@ -147,7 +147,7 @@ Socket(AF_INET, SOCK_DGRAM, 0)
 
 #ifdef  CCXX_IPV6
 SocketPort::SocketPort(SocketService *svc, const IPV6Address &ia, tpport_t port) :
-Socket(AF_INET6, SOCK_DGRAM, 0)
+Socket(AF_INET6, SOCK_DGRAM, IPPROTO_UDP)
 {
 #ifdef WIN32
 	// FIXME: error handling
@@ -180,7 +180,7 @@ Socket(AF_INET6, SOCK_DGRAM, 0)
 #endif
 
 SocketPort::SocketPort(SocketService *svc, const IPV4Host &ih, tpport_t port) :
-Socket(AF_INET, SOCK_STREAM, 0)
+Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 {
 #ifdef WIN32
 	// FIXME: error handling
@@ -248,7 +248,7 @@ Socket(AF_INET, SOCK_STREAM, 0)
 
 #ifdef  CCXX_IPV6
 SocketPort::SocketPort(SocketService *svc, const IPV6Host &ih, tpport_t port) :
-Socket(AF_INET6, SOCK_STREAM, 0)
+Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 {
 #ifdef WIN32
 	// FIXME: error handling
