@@ -201,6 +201,40 @@ char *lsetField(char *dest, size_t size, const char *src, const char fill)
 	return dest;
 }
 
+char *setUpper(char *string, size_t size)
+{
+	char *ret = string;
+
+	if(!size)
+		size = strlen(string);
+
+	while(size && *string)
+	{
+		*string = toupper(*string);
+		++string;
+		--size;
+	}
+
+	return ret;
+}
+
+char *setLower(char *string, size_t size)
+{
+        char *ret = string;
+
+        if(!size)
+                size = strlen(string);
+
+        while(size && *string)
+        {
+                *string = tolower(*string); 
+                ++string;
+                --size;
+        }
+
+        return ret;
+} 	
+
 char *setString(char *dest, size_t size, const char *src)
 {
         size_t len = strlen(src);
